==> membersOnly.2.0.4.zip: membersOnly/membersOnly.php <==
<?php if(!defined('PLX_ROOT')) exit;
	/**
		* Plugin 			membersOnly
		*
		* @CMS required			PluXml 
		*
		* @version			2.0.3
		* @date				19/02/2025
		* @author 			Gcyrillus
		░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
		░       ░░  ░░░░░░░  ░░░░  ░  ░░░░  ░░      ░░       ░░░      ░░  ░░░░░░░        ░░      ░░░░░   ░░░  ░        ░        ░
		▒  ▒▒▒▒  ▒  ▒▒▒▒▒▒▒  ▒▒▒▒  ▒▒  ▒▒  ▒▒  ▒▒▒▒  ▒  ▒▒▒▒  ▒  ▒▒▒▒  ▒  ▒▒▒▒▒▒▒▒▒▒  ▒▒▒▒  ▒▒▒▒▒▒▒▒▒▒    ▒▒  ▒  ▒▒▒▒▒▒▒▒▒▒  ▒▒▒▒
		▓       ▓▓  ▓▓▓▓▓▓▓  ▓▓▓▓  ▓▓▓    ▓▓▓  ▓▓▓▓  ▓       ▓▓  ▓▓▓▓  ▓  ▓▓▓▓▓▓▓▓▓▓  ▓▓▓▓▓      ▓▓▓▓▓  ▓  ▓  ▓      ▓▓▓▓▓▓  ▓▓▓▓
		█  ███████  ███████  ████  ██  ██  ██  ████  █  ███████  ████  █  ██████████  ██████████  ████  ██    █  ██████████  ████
		█  ███████        ██      ██  ████  ██      ██  ████████      ██        █        ██      ██  █  ███   █        ████  ████
		█████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████
	**/
	class membersOnly extends plxPlugin {
		const BEGIN_CODE = '<?php' . PHP_EOL;
		const END_CODE = PHP_EOL . '?>';
		public $lang = ''; 
		public $statiques;
		public $categories;
		public $articles;
		public $paginateBy;
		
		public function __construct($default_lang) {

			# gestion du multilingue plxMyMultiLingue
			$this->lang='';
			if(defined('PLX_MYMULTILINGUE')) {
				$lang = plxMyMultiLingue::_Lang();
				if(!empty($lang)) {
					if(isset($_SESSION['default_lang']) AND $_SESSION['default_lang']!=$lang) {
						$this->lang = $lang.'/';
					}
				}
			}


			parent::__construct($default_lang);
			# droits pour accèder à la page admin.php du plugin
			$this->setAdminProfil(PROFIL_ADMIN, PROFIL_MANAGER);
			
			
			$this->statiques  = $this->getParam('statiques')  ==''   ?   null : $this->getParam('statiques') ;
			$this->articles   = $this->getParam('articles')   ==''   ?   null : $this->getParam('articles') ;
			$this->categories = $this->getParam('categories') ==''   ?   null : $this->getParam('categories') ;
			$this->paginateBy = $this->getParam('paginate')   ==''   ?   10   : $this->getParam('paginate') ;
			
			# Declaration des hooks		
			$this->addHook('Index', 'Index');	
			$this->addHook('log', 'log');
			$this->addHook('SitemapBegin', 'Index');
			$this->addHook('AdminArticlePrepend','AdminArticlePrepend');
			$this->addHook('AdminTopBottom','AdminTopBottom');
			$this->addHook('AdminArticleTop','AdminArticleTop');
			

		}
		/**
			* 
			* Méthode qui enregistre le statut d'un article à l'edition
			* 
			* @author		: TheCrok
			*
		**/
		public function AdminArticlePrepend() {
			echo '<?php
				$plug = $plxAdmin->plxPlugins->getInstance(\''.basename(__DIR__).'\');
				$records=json_decode($plug->articles,true);
				$done=false;
				if(!empty($_POST)) {
					# effacement d\'un filtre
					if(!isset($_POST[\'updateArt\'])) {
						foreach($records as $k => $v){
							if(substr($v,0,4) == $_POST[\'artId\']) {
								unset($records[$k]);	
								$done=true;
								break;
							}
						}
					}
					# mise à jour d\'un filtre
					elseif(isset($_POST[\'updateArt\'])) {
						foreach($records as $k => $v){
							$mod[$k]= explode(\',\',$v);
							if(isset($_POST[\'updateArt\']) && $mod[$k][0]== $_POST[\'updateArt\'] && isset($mod[$k][1])){
								$records[$k] = $mod[$k][0].\',\'.$_POST[\'radioArt-\'.$mod[$k][0]];	
								$done=true;
								break;
							}
						}
					}
					# ajout  d\'un filtre
					if($done == false && isset($_POST[\'updateArt\'])) $records[] = $_POST[\'updateArt\'].\',\'.$_POST[\'radioArt-\'.$_POST[\'updateArt\']];
					# fichier langue
					loadLang(PLX_CORE.\'lang/\'.$lang.\'/admin.php\');
					# mise à jour des paramêtres
					$plug->setParam(\'articles\', json_encode($records,true), \'cdata\');
					$plug->saveParams();
				}
			?>';
		}		
		
		/**
			* Méthode qui affiche un message si le plugin n'a pas la langue du site dans sa traduction
			* @return	stdio
			* @author	Stephane F
		**/
		public function AdminTopBottom() {
			echo '<?php
			$file = PLX_PLUGINS."'.$this->plug['name'].'/lang/".$plxAdmin->aConf["default_lang"].".php";
			if(!file_exists($file)) {
			echo "<p class=\\"warning\\">'.basename(__DIR__).'<br />".sprintf("'.$this->getLang('L_LANG_UNAVAILABLE').'", $file)."</p>";
			plxMsg::Display();
			}
			?>';
		}
		
		/** 
			* Méthode Index
			* 
			* Descrition	: Filtre les pages,articles ou catégories non accessibles au public
			* @author		: TheCrok
			*
			* 
		**/
		public function Index() {
			# filtrage depuis les paramêtres du plugin 
			# Pages statiques
			$stats = $this->statiques;
			echo self::BEGIN_CODE;
			?>
			$stats=array(<?= $stats?>);
			$filters=array();
			if(isset($stats[0]))
			foreach($stats[0] as $k => $v){
				$get= explode(',',$v);
					$filters[$get[0]]= $get[0];
					if(isset($get[1])) $filters[$get[0]]= $get[1];
					else $filters[$get[0]]= 0;
			}
			foreach($plxMotor->aStats as $stat_num => $stat) {
			if(!isset($_SESSION['profil']) && isset($filters[$stat_num])) {unset($plxMotor->aStats[$stat_num]);}			
			if(isset($_SESSION['profil']) && isset($filters[$stat_num]) && $_SESSION['profil'] > $filters[$stat_num] ) {unset($plxMotor->aStats[$stat_num]);}
			}
			<?php
			echo self::END_CODE;
			
			# Pages categories
			$cats = $this->categories;
			echo self::BEGIN_CODE;
			?>
			$cats=array(<?= $cats ?>);
			if(isset($cats[0]))
			foreach($cats[0] as $k => $v){
				$get= explode(',',$v);
					$filters[$get[0]]= $get[0];
					if(isset($get[1])) $filters[$get[0]]= $get[1];
					else $filters[$get[0]]= 0;
			}			
			foreach($plxMotor->aCats as $cat_num => $infos) {
			if(!isset($_SESSION['profil']) && isset($filters[$cat_num])) {unset($plxMotor->aCats[$cat_num]);}			
			if(isset($_SESSION['profil']) && isset($filters[$cat_num]) && $_SESSION['profil'] >= $filters[$cat_num] ) {unset($plxMotor->aCats[$cat_num]);}
			}
			<?php
			echo self::END_CODE;
			
			# Articles et leurs commentaires
			$arts   = $this->articles;
			echo self::BEGIN_CODE;
			?>
			$arts=array(<?= $arts ?>);
			if(isset($arts[0]))
			foreach($arts[0] as $k => $v){
			$get= explode(',',$v);
				$filters[$get[0]]= $get[0];
					if(isset($get[1])) $filters[$get[0]]= $get[1];
					else $filters[$get[0]]= 0;
			}				
			foreach($plxMotor->plxGlob_arts->aFiles as $art_num => $file) {
			if(!isset($_SESSION['profil']) && isset($filters[$art_num])) {
				unset($plxMotor->plxGlob_arts->aFiles[$art_num]);
					foreach($plxMotor->plxGlob_coms->aFiles as $com=>$comFile) {
						if(substr($comFile, 0, 4) == $art_num) unset($plxMotor->plxGlob_coms->aFiles[$com]);
					}
				}			
			if(isset($_SESSION['profil']) && isset($filters[$art_num]) && $_SESSION['profil'] >= $filters[$art_num] ) {
				unset($plxMotor->plxGlob_arts->aFiles[$art_num]);
					foreach($plxMotor->plxGlob_coms->aFiles as $com=>$comFile) {
						if(substr($comFile, 0, 4) == $art_num) unset($plxMotor->plxGlob_coms->aFiles[$com]);
					}
				}
			}
			<?php
			echo self::END_CODE;
			
		}
		
		public function AdminArticleTop() {
		$filter = $this->articles;
		echo '<?php
				$id=$artId;
				if($artId == \'0000\' OR $artId == \'\')
					$id = $plxAdmin->nextIdArticle();		
				$filter='.$this->articles.';		
				# profils utilisateurs
				# Tableau des profils
				$aProfils = array(
					PROFIL_ADMIN => L_PROFIL_ADMIN,
					PROFIL_MANAGER => L_PROFIL_MANAGER,
					PROFIL_MODERATOR => L_PROFIL_MODERATOR,
					PROFIL_EDITOR => L_PROFIL_EDITOR,
					PROFIL_WRITER => L_PROFIL_WRITER
				);
				$offPlugins= $plxAdmin->plxPlugins->getInactivePlugins();
				//var_dump( $offPlugins[\'StaticMiniForum\']);
				if(isset($plxAdmin->plxPlugins->aPlugins[\'StaticMiniForum\']) && !in_array(\'StaticMiniForum\',$offPlugins)) {
					$plugInstance=$plxAdmin->plxPlugins->getInstance(\'StaticMiniForum\');
					$aProfils = $plugInstance->memberProfils;
				}
				$profilTypes =count($aProfils);
				#inversion du tableau pour des raisons pratiques
				$aProfils=array_reverse($aProfils,true);
			
			
				$checked=$lev=$levelChecked=$radioarts=$profilsHeader=\'\';
				$filter='.$this->articles.';
				if($filter != null && trim($filter[0]) !=\'\') {

				foreach($filter as $filters){
					$filters= explode(\',\',$filters);
					if(isset($filters[0]) && !isset($filters[1])) $filters[1] =1;// defaut profil gestionnaire
					if(isset($filters[0]) && ( !isset($filters[1])|| $filters[1] == $profilTypes || $filters[1]==\'\')) $filters[1] = 4;
					$level[$filters[0]]	= $filters[1];		
				}
					foreach($aProfils as $lev => $str) {
					$profilsHeader .= \'<th>\'.$str.\'</th>\';
						$levelChecked=\'\';
						if(isset($level[$id])) {
							if($lev == $level[$id]) {
								$checked=\'checked\';
								$levelChecked=\'checked\';
							}
						}
						$radioarts .=\'<td class="rp">					
						<input type="radio" name="radioArt-\'.$id.\'" id="radio-\'.$id.$lev.\'" \'.$levelChecked.\' value="\'.$lev.\'">
						<sup>(\'.$lev.\')</sup>
						</td>\'.PHP_EOL;
					}
				}
			echo \'	<table id="tableArts">
			<thead><tr><td><img src="\'.PLX_PLUGINS.\'membersOnly/icon.png" height="30" width="30"></td><th>\'.L_ARTICLES_FILTER_BUTTON.\'</th>\'.$profilsHeader.\'</tr></thead><tbody>
				<tr>
					<th><b>\'.L_PROFIL.\'</b></th>
					<td><input type="checkbox" id ="art-\'.$id.\'" name="updateArt" \'.$checked.\' value="\'.$id.\'"></td>
					\'.$radioarts.\'
				</tr>
			</tbody>
		</table>
		<style>
				tr:hover> td{
				  box-shadow:inset 0 0 0 20px #ADD8E644;
				}
				table tr> :nth-child(2){
				  border-inline-end: solid black;
				}
				tr:has(input:checked),
				tr:has(input:checked) td:not(td.rp:has(input:checked)) ~ td[class] {
				  background: #FFC0C0;
				  background: linear-gradient(#F00,#F00) 0 0 / 100% 2px no-repeat;
				  color:#F50;
				}

				/*tr:not(:has(.rp input:checked)) td,
				tr:not(:has(td.rp input:checked)) td.rp,*/
				tr:has(td.rp input:checked) td ~ td.rp:has(input:checked),
				table tr td.rp:has(input:checked) ~ td.rp:not(:has(input:checked)) {
				  background: #E1FBE1;
				}
				table#tableArts {
				  margin:0.5em 1em;
				  border:solid 1px;
				  width:clamp(350px, 960px, calc(100% - 4em));
					table-layout:fixed;
				}

				table#tableArts tr>*:not(:first-child) {
				  text-align: center;
				}

				table#tableArts tr> *,
				table#tableArts label {
				  overflow: hidden;
				  white-space: nowrap;
				  text-overflow: ellipsis;
				}
		</style>
		<script>
			function checkRadios(disabledRadios) {
			let allRadios = document.querySelectorAll("table tbody tr input[type=radio]");
			allRadios.forEach((el) => {
				el.removeAttribute("disabled");
			});

			disabledRadios.forEach((el) => {
				el.setAttribute("disabled", "disabled");
				el.removeAttribute("checked");
			});
			}
			let disabledRadios = document.querySelectorAll("table tbody tr:not(:has(td.rp input:checked)) input[type=radio]");
			let checkBoxe = document.querySelector("table tbody tr input[type=checkbox]");

			checkBoxe.addEventListener("change", () => {
					let Radios = checkBoxe.closest("tr").querySelectorAll("input[type=radio]");
					checkRadios(disabledRadios);
					if (checkBoxe.checked) {
						checkBoxe.setAttribute("checked", "checked");
						Radios.forEach((r) => {
							r.removeAttribute("disabled");
						});
						Radios[0].checked = true;
					} else {
						Radios.forEach((r) => {
							r.setAttribute("disabled", "disabled");
							r.checked = false;
							checkBoxe.removeAttribute("checked", "checked");
						});
					}
				});

			window.addEventListener("load", checkRadios(disabledRadios));
		</script>
			\';
		?>';
		}
		
		
		/**
			* hook thème:	bouton de connexion/deconnexion
			*
			* Auteur: 		GC-Nomade
			*
		**/
		public function log() {
		echo '<?php 
				# chargement du fichier langue de l\'admin
				loadLang(PLX_CORE.\'lang/\'.$plxShow->plxMotor->aConf[\'default_lang\'].\'\/admin.php\');
				$amp=\'&\';
				if($plxShow->plxMotor->get ==\'home\' || $_SERVER[\'REQUEST_URI\'] ==\'/\' || $_SERVER[\'REQUEST_URI\'] == DIRECTORY_SEPARATOR ) $amp=\'?\';
				# deconnexion
				if(isset($_GET[\'logout\'])) {
					$_SESSION = array();
					session_destroy();
					header(\'Location:index.php?\'. substr($plxShow->plxMotor->get,0,strpos($plxShow->plxMotor->get,$amp)));
					exit;
				}
				# connexion
				elseif(isset($_SESSION[\'profil\'])) echo \'<a href="\'. htmlentities($_SERVER[\'REQUEST_URI\']).$amp.\'logout" id="log" class="out">\'.L_ADMIN_LOGOUT.\'</a>\';
				# non connecté
				else {
					echo \'<a href="./core/admin/auth.php?p=\'. htmlentities($_SERVER[\'REQUEST_URI\']).\'" id="log" class="in">\'.L_LOST_PASSWORD_LOGIN.\'</a>\';
					
				}
		?>';
		
		}
	}

==> membersOnly.2.0.5.zip: membersOnly/membersOnly.php <==
<?php if(!defined('PLX_ROOT')) exit;
	/**
		* Plugin 			membersOnly
		*
		* @CMS required			PluXml 
		*
		* @version			2.0.3
		* @date				19/02/2025
		* @author 			Gcyrillus
		░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
		░       ░░  ░░░░░░░  ░░░░  ░  ░░░░  ░░      ░░       ░░░      ░░  ░░░░░░░        ░░      ░░░░░   ░░░  ░        ░        ░
		▒  ▒▒▒▒  ▒  ▒▒▒▒▒▒▒  ▒▒▒▒  ▒▒  ▒▒  ▒▒  ▒▒▒▒  ▒  ▒▒▒▒  ▒  ▒▒▒▒  ▒  ▒▒▒▒▒▒▒▒▒▒  ▒▒▒▒  ▒▒▒▒▒▒▒▒▒▒    ▒▒  ▒  ▒▒▒▒▒▒▒▒▒▒  ▒▒▒▒
		▓       ▓▓  ▓▓▓▓▓▓▓  ▓▓▓▓  ▓▓▓    ▓▓▓  ▓▓▓▓  ▓       ▓▓  ▓▓▓▓  ▓  ▓▓▓▓▓▓▓▓▓▓  ▓▓▓▓▓      ▓▓▓▓▓  ▓  ▓  ▓      ▓▓▓▓▓▓  ▓▓▓▓
		█  ███████  ███████  ████  ██  ██  ██  ████  █  ███████  ████  █  ██████████  ██████████  ████  ██    █  ██████████  ████
		█  ███████        ██      ██  ████  ██      ██  ████████      ██        █        ██      ██  █  ███   █        ████  ████
		█████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████
	**/
	class membersOnly extends plxPlugin {
		const BEGIN_CODE = '<?php' . PHP_EOL;
		const END_CODE = PHP_EOL . '?>';
		public $lang = ''; 
		public $statiques;
		public $categories;
		public $articles;
		public $paginateBy;
		
		public function __construct($default_lang) {

			# gestion du multilingue plxMyMultiLingue
			$this->lang='';
			if(defined('PLX_MYMULTILINGUE')) {
				$lang = plxMyMultiLingue::_Lang();
				if(!empty($lang)) {
					if(isset($_SESSION['default_lang']) AND $_SESSION['default_lang']!=$lang) {
						$this->lang = $lang.'/';
					}
				}
			}


			parent::__construct($default_lang);
			# droits pour accèder à la page admin.php du plugin
			$this->setAdminProfil(PROFIL_ADMIN, PROFIL_MANAGER);
			
			
			$this->statiques  = $this->getParam('statiques')  ==''   ?   null : $this->getParam('statiques') ;
			$this->articles   = $this->getParam('articles')   ==''   ?   null : $this->getParam('articles') ;
			$this->categories = $this->getParam('categories') ==''   ?   null : $this->getParam('categories') ;
			$this->paginateBy = $this->getParam('paginate')   ==''   ?   10   : $this->getParam('paginate') ;
			
			# Declaration des hooks		
			$this->addHook('Index', 'Index');	
			$this->addHook('log', 'log');
			$this->addHook('SitemapBegin', 'Index');
			$this->addHook('AdminArticlePrepend','AdminArticlePrepend');
			$this->addHook('AdminTopBottom','AdminTopBottom');
			$this->addHook('AdminArticleTop','AdminArticleTop');
			

		}
		/**
			* 
			* Méthode qui enregistre le statut d'un article à l'edition
			* 
			* @author		: TheCrok
			*
		**/
		public function AdminArticlePrepend() {
			echo '<?php
				$plug = $plxAdmin->plxPlugins->getInstance(\''.basename(__DIR__).'\');
				$records=json_decode($plug->articles,true);
				$done=false;
				if(!empty($_POST)) {
					# effacement d\'un filtre
					if(!isset($_POST[\'updateArt\'])) {
						foreach($records as $k => $v){
							if(substr($v,0,4) == $_POST[\'artId\']) {
								unset($records[$k]);	
								$done=true;
								break;
							}
						}
					}
					# mise à jour d\'un filtre
					elseif(isset($_POST[\'updateArt\'])) {
						foreach($records as $k => $v){
							$mod[$k]= explode(\',\',$v);
							if(isset($_POST[\'updateArt\']) && $mod[$k][0]== $_POST[\'updateArt\'] && isset($mod[$k][1])){
								$records[$k] = $mod[$k][0].\',\'.$_POST[\'radioArt-\'.$mod[$k][0]];	
								$done=true;
								break;
							}
						}
					}
					# ajout  d\'un filtre
					if($done == false && isset($_POST[\'updateArt\'])) $records[] = $_POST[\'updateArt\'].\',\'.$_POST[\'radioArt-\'.$_POST[\'updateArt\']];
					# fichier langue
					loadLang(PLX_CORE.\'lang/\'.$lang.\'/admin.php\');
					# mise à jour des paramêtres
					$plug->setParam(\'articles\', json_encode($records,true), \'cdata\');
					$plug->saveParams();
				}
			?>';
		}		
		
		/**
			* Méthode qui affiche un message si le plugin n'a pas la langue du site dans sa traduction
			* @return	stdio
			* @author	Stephane F
		**/
		public function AdminTopBottom() {
			echo '<?php
			$file = PLX_PLUGINS."'.$this->plug['name'].'/lang/".$plxAdmin->aConf["default_lang"].".php";
			if(!file_exists($file)) {
			echo "<p class=\\"warning\\">'.basename(__DIR__).'<br />".sprintf("'.$this->getLang('L_LANG_UNAVAILABLE').'", $file)."</p>";
			plxMsg::Display();
			}
			?>';
		}
		
		/** 
			* Méthode Index
			* 
			* Descrition	: Filtre les pages,articles ou catégories non accessibles au public
			* @author		: TheCrok
			*
			* 
		**/
		public function Index() {
			# filtrage depuis les paramêtres du plugin 
			# Pages statiques
			$stats = $this->statiques;
			echo self::BEGIN_CODE;
			?>
			$stats=array(<?= $stats?>);
			$filters=array();
			if(isset($stats[0]))
			foreach($stats[0] as $k => $v){
				$get= explode(',',$v);
					$filters[$get[0]]= $get[0];
					if(isset($get[1])) $filters[$get[0]]= $get[1];
					else $filters[$get[0]]= 0;
			}
			foreach($plxMotor->aStats as $stat_num => $stat) {
			if(!isset($_SESSION['profil']) && isset($filters[$stat_num])) {unset($plxMotor->aStats[$stat_num]);}			
			if(isset($_SESSION['profil']) && isset($filters[$stat_num]) && $_SESSION['profil'] > intval($filters[$stat_num]) ) {unset($plxMotor->aStats[$stat_num]);}
			}
			<?php
			echo self::END_CODE;
			
			# Pages categories
			$cats = $this->categories;
			echo self::BEGIN_CODE;
			?>
			$cats=array(<?= $cats ?>);
			if(isset($cats[0]))
			foreach($cats[0] as $k => $v){
				$get= explode(',',$v);
					$filters[$get[0]]= $get[0];
					if(isset($get[1])) $filters[$get[0]]= $get[1];
					else $filters[$get[0]]= 0;
			}			
			foreach($plxMotor->aCats as $cat_num => $infos) {
			if(!isset($_SESSION['profil']) && isset($filters[$cat_num])) {unset($plxMotor->aCats[$cat_num]);}			
			if(isset($_SESSION['profil']) && isset($filters[$cat_num]) && $_SESSION['profil'] >= $filters[$cat_num] ) {unset($plxMotor->aCats[$cat_num]);}
			}
			<?php
			echo self::END_CODE;
			
			# Articles et leurs commentaires
			$arts   = $this->articles;
			echo self::BEGIN_CODE;
			?>
			$arts=array(<?= $arts ?>);
			if(isset($arts[0]))
			foreach($arts[0] as $k => $v){
			$get= explode(',',$v);
				$filters[$get[0]]= $get[0];
					if(isset($get[1])) $filters[$get[0]]= $get[1];
					else $filters[$get[0]]= 0;
			}				
			foreach($plxMotor->plxGlob_arts->aFiles as $art_num => $file) {
			if(!isset($_SESSION['profil']) && isset($filters[$art_num])) {
				unset($plxMotor->plxGlob_arts->aFiles[$art_num]);
					foreach($plxMotor->plxGlob_coms->aFiles as $com=>$comFile) {
						if(substr($comFile, 0, 4) == $art_num) unset($plxMotor->plxGlob_coms->aFiles[$com]);
					}
				}			
			if(isset($_SESSION['profil']) && isset($filters[$art_num]) && $_SESSION['profil'] >= $filters[$art_num] ) {
				unset($plxMotor->plxGlob_arts->aFiles[$art_num]);
					foreach($plxMotor->plxGlob_coms->aFiles as $com=>$comFile) {
						if(substr($comFile, 0, 4) == $art_num) unset($plxMotor->plxGlob_coms->aFiles[$com]);
					}
				}
			}
			<?php
			echo self::END_CODE;
			
		}
		
		public function AdminArticleTop() {
		$filter = $this->articles;
		echo '<?php
				$id=$artId;
				if($artId == \'0000\' OR $artId == \'\')
					$id = $plxAdmin->nextIdArticle();		
				$filter='.$this->articles.';		
				# profils utilisateurs
				# Tableau des profils
				$aProfils = array(
					PROFIL_ADMIN => L_PROFIL_ADMIN,
					PROFIL_MANAGER => L_PROFIL_MANAGER,
					PROFIL_MODERATOR => L_PROFIL_MODERATOR,
					PROFIL_EDITOR => L_PROFIL_EDITOR,
					PROFIL_WRITER => L_PROFIL_WRITER
				);
				$offPlugins= $plxAdmin->plxPlugins->getInactivePlugins();
				//var_dump( $offPlugins[\'StaticMiniForum\']);
				if(isset($plxAdmin->plxPlugins->aPlugins[\'StaticMiniForum\']) && !in_array(\'StaticMiniForum\',$offPlugins)) {
					$plugInstance=$plxAdmin->plxPlugins->getInstance(\'StaticMiniForum\');
					$aProfils = $plugInstance->memberProfils;
				}
				$profilTypes =count($aProfils);
				#inversion du tableau pour des raisons pratiques
				$aProfils=array_reverse($aProfils,true);
			
			
				$checked=$lev=$levelChecked=$radioarts=$profilsHeader=\'\';
				$filter='.$this->articles.';
				if($filter != null && trim($filter[0]) !=\'\') {

				foreach($filter as $filters){
					$filters= explode(\',\',$filters);
					if(isset($filters[0]) && !isset($filters[1])) $filters[1] =1;// defaut profil gestionnaire
					if(isset($filters[0]) && ( !isset($filters[1])|| $filters[1] == $profilTypes || $filters[1]==\'\')) $filters[1] = 4;
					$level[$filters[0]]	= $filters[1];		
				}
					foreach($aProfils as $lev => $str) {
					$profilsHeader .= \'<th>\'.$str.\'</th>\';
						$levelChecked=\'\';
						if(isset($level[$id])) {
							if($lev == $level[$id]) {
								$checked=\'checked\';
								$levelChecked=\'checked\';
							}
						}
						$radioarts .=\'<td class="rp">					
						<input type="radio" name="radioArt-\'.$id.\'" id="radio-\'.$id.$lev.\'" \'.$levelChecked.\' value="\'.$lev.\'">
						<sup>(\'.$lev.\')</sup>
						</td>\'.PHP_EOL;
					}
				}
			echo \'	<table id="tableArts">
			<thead><tr><td><img src="\'.PLX_PLUGINS.\'membersOnly/icon.png" height="30" width="30"></td><th>\'.L_ARTICLES_FILTER_BUTTON.\'</th>\'.$profilsHeader.\'</tr></thead><tbody>
				<tr>
					<th><b>\'.L_PROFIL.\'</b></th>
					<td><input type="checkbox" id ="art-\'.$id.\'" name="updateArt" \'.$checked.\' value="\'.$id.\'"></td>
					\'.$radioarts.\'
				</tr>
			</tbody>
		</table>
		<style>
				tr:hover> td{
				  box-shadow:inset 0 0 0 20px #ADD8E644;
				}
				table tr> :nth-child(2){
				  border-inline-end: solid black;
				}
				tr:has(input:checked),
				tr:has(input:checked) td:not(td.rp:has(input:checked)) ~ td[class] {
				  background: #FFC0C0;
				  background: linear-gradient(#F00,#F00) 0 0 / 100% 2px no-repeat;
				  color:#F50;
				}

				/*tr:not(:has(.rp input:checked)) td,
				tr:not(:has(td.rp input:checked)) td.rp,*/
				tr:has(td.rp input:checked) td ~ td.rp:has(input:checked),
				table tr td.rp:has(input:checked) ~ td.rp:not(:has(input:checked)) {
				  background: #E1FBE1;
				}
				table#tableArts {
				  margin:0.5em 1em;
				  border:solid 1px;
				  width:clamp(350px, 960px, calc(100% - 4em));
					table-layout:fixed;
				}

				table#tableArts tr>*:not(:first-child) {
				  text-align: center;
				}

				table#tableArts tr> *,
				table#tableArts label {
				  overflow: hidden;
				  white-space: nowrap;
				  text-overflow: ellipsis;
				}
		</style>
		<script>
			function checkRadios(disabledRadios) {
			let allRadios = document.querySelectorAll("table tbody tr input[type=radio]");
			allRadios.forEach((el) => {
				el.removeAttribute("disabled");
			});

			disabledRadios.forEach((el) => {
				el.setAttribute("disabled", "disabled");
				el.removeAttribute("checked");
			});
			}
			let disabledRadios = document.querySelectorAll("table tbody tr:not(:has(td.rp input:checked)) input[type=radio]");
			let checkBoxe = document.querySelector("table tbody tr input[type=checkbox]");

			checkBoxe.addEventListener("change", () => {
					let Radios = checkBoxe.closest("tr").querySelectorAll("input[type=radio]");
					checkRadios(disabledRadios);
					if (checkBoxe.checked) {
						checkBoxe.setAttribute("checked", "checked");
						Radios.forEach((r) => {
							r.removeAttribute("disabled");
						});
						Radios[0].checked = true;
					} else {
						Radios.forEach((r) => {
							r.setAttribute("disabled", "disabled");
							r.checked = false;
							checkBoxe.removeAttribute("checked", "checked");
						});
					}
				});

			window.addEventListener("load", checkRadios(disabledRadios));
		</script>
			\';
		?>';
		}
		
		
		/**
			* hook thème:	bouton de connexion/deconnexion
			*
			* Auteur: 		GC-Nomade
			*
		**/
		public function log() {
		echo '<?php 
				# chargement du fichier langue de l\'admin
				loadLang(PLX_CORE.\'lang/\'.$plxShow->plxMotor->aConf[\'default_lang\'].\'\/admin.php\');
				$amp=\'&\';
				if($plxShow->plxMotor->get ==\'home\' || $_SERVER[\'REQUEST_URI\'] ==\'/\' || $_SERVER[\'REQUEST_URI\'] == DIRECTORY_SEPARATOR ) $amp=\'?\';
				# deconnexion
				if(isset($_GET[\'logout\'])) {
					$_SESSION = array();
					session_destroy();
					header(\'Location:index.php?\'. substr($plxShow->plxMotor->get,0,strpos($plxShow->plxMotor->get,$amp)));
					exit;
				}
				# connexion
				elseif(isset($_SESSION[\'profil\'])) echo \'<a href="\'. htmlentities($_SERVER[\'REQUEST_URI\']).$amp.\'logout" id="log" class="out">\'.L_ADMIN_LOGOUT.\'</a>\';
				# non connecté
				else {
					echo \'<a href="./core/admin/auth.php?p=\'. htmlentities($_SERVER[\'REQUEST_URI\']).\'" id="log" class="in">\'.L_LOST_PASSWORD_LOGIN.\'</a>\';
					
				}
		?>';
		
		}
	}
